@@ -287,6 +287,22 @@ class AdvancedHTMLParser(HTMLParser):
         '''
         self.root = root
 
+
+    def setDoctype(self, newDoctype):
+        '''
+            setDoctype - Set the doctype for this document, or clear it.
+
+                @param newDoctype <str/None> -
+
+                    If None, will clear the doctype and not return one with #getHTML
+
+                    Otherwise, a string of the full doctype tag.
+
+                      For example, the HTML5 doctype would be "DOCTYPE html"
+        '''
+        self.doctype = newDoctype
+
+
     def getElementsByTagName(self, tagName, root='root'):
         '''
             getElementsByTagName - Searches and returns all elements with a specific tag name.
@@ -363,13 +379,20 @@ class AdvancedHTMLParser(HTMLParser):
         '''
             getElementsByClassName - Searches and returns all elements containing a given class name.
 
-                @param className <str> - A one-word class name
+                @param className <str> - One or more space-separated class names
+
                 @param root <AdvancedTag/'root'> - Search starting at a specific node, if provided. if string 'root' [default], the root of the parsed tree will be used.
         '''
         (root, isFromRoot) = self._handleRootArg(root)
 
         elements = []
 
+        # Generate list of all classnames to match
+        classNames = [x.strip() for x in className.strip().split(' ') if x.strip()]
+
+        # Run through entire tree on the first
+        className = classNames.pop(0)
+
         if isFromRoot is True and className in root.classNames:
             elements.append(root)
 
@@ -381,6 +404,11 @@ class AdvancedHTMLParser(HTMLParser):
 
             elements += getElementsByClassName(className, child)
 
+
+        # Check if we need to match against any other names
+        if len(classNames) > 0:
+            elements = [ em for em in elements for matchClassName in classNames  if matchClassName in em.classList ]
+
         return TagCollection(elements)
 
     def getElementsByAttr(self, attrName, attrValue, root='root'):
@@ -1120,6 +1148,7 @@ class IndexedAdvancedHTMLParser(AdvancedHTMLParser):
 #                 Public
 ##########################################################
 
+
     # This should be called if you modify a parsed tree at an element level, then search it.
     def reindex(self, newIndexIDs=None, newIndexNames=None, newIndexClassNames=None, newIndexTagNames=None):
         '''
@@ -1259,8 +1288,11 @@ class IndexedAdvancedHTMLParser(AdvancedHTMLParser):
         '''
             getElementsByClassName - Searches and returns all elements containing a given class name.
 
-                @param className <str> - A one-word class name
+
+                @param className <str> - One or more space-separated class names
+
                 @param root <AdvancedTag/'root'> - Search starting at a specific node, if provided. if string 'root', the root of the parsed tree will be used.
+
                 @param useIndex <bool> If useIndex is True and class names are indexed [see constructor] only the index will be used. Otherwise a full search is performed.
         '''
         (root, isFromRoot) = self._handleRootArg(root)
